<script setup>
import { ref, reactive } from 'vue';
import { useRouter } from "vue-router";
import { get, post, postForm } from '@/utils/request.js'
import { message, Modal } from 'ant-design-vue';
import { logout } from '@/config.js';
import { formatMessage } from '@/utils/localeUtils.js';
import useTableSearch from '@/utils/tableUtils.jsx';
import SelectLocDetlView from '@/components/locDetl/selectLocDetl/index.vue'

const router = useRouter();

const TABLE_KEY = 'table-locDetl';
const selectLocDetlChild = ref(null)
const selectLocDetlViewShow = ref(false)

let tableData = ref([]);
getColumns();

const {
    getColumnSearchProps,
    handleResizeColumn,
} = useTableSearch();

const state = reactive({
    selectedRowKeys: [],
    loading: false,
    columns: [],
});
const onSelectChange = selectedRowKeys => {
    // console.log('selectedRowKeys changed: ', selectedRowKeys);
    state.selectedRowKeys = selectedRowKeys;
};

state.columns = [
    {
        title: formatMessage('db.man_loc_detl.anfme', '库存数量'),
        dataIndex: 'anfme',
        width: 140,
        ellipsis: true,
    },
    {
        title: formatMessage('db.man_loc_detl.loc_id', '库位'),
        dataIndex: 'locId$',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('locId$'),
    },
    {
        title: formatMessage('db.man_loc_detl.loc_no', '库位号'),
        dataIndex: 'locNo',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('locNo'),
    },
    {
        title: formatMessage('db.man_loc_detl.mat_id', '商品'),
        dataIndex: 'matId$',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('matId$'),
    },
    {
        title: formatMessage('db.man_loc_detl.matnr', '商品编号'),
        dataIndex: 'matnr',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('matnr'),
    },
    {
        title: formatMessage('db.man_loc_detl.order_no', '订单号'),
        dataIndex: 'orderNo',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('orderNo'),
    },
    {
        title: formatMessage('db.man_loc_detl.batch', '批号'),
        dataIndex: 'batch',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('batch'),
    },
    {
        title: formatMessage('db.man_loc_detl.anfme', '数量'),
        dataIndex: 'anfme',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('anfme'),
    },
    {
        title: formatMessage('db.man_loc_detl.freeze', '是否冻结'),
        dataIndex: 'freeze$',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('freeze$'),
    },
    {
        title: formatMessage('db.man_loc_detl.status', '状态'),
        dataIndex: 'status$',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('status$'),
    },
    // {
    //   title: formatMessage('db.man_loc_detl.create_time', '添加时间'),
    //   dataIndex: 'createTime$',
    //   width: 140,
    //   ellipsis: true,
    //   ...getColumnSearchProps('createTime$'),
    // },
    // {
    //   title: formatMessage('db.man_loc_detl.create_by', '添加人员'),
    //   dataIndex: 'createBy$',
    //   width: 140,
    //   ellipsis: true,
    //   ...getColumnSearchProps('createBy$'),
    // },
    {
        title: formatMessage('db.man_loc_detl.update_time', '修改时间'),
        dataIndex: 'updateTime$',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('updateTime$'),
    },
    {
        title: formatMessage('db.man_loc_detl.update_by', '修改人员'),
        dataIndex: 'updateBy$',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('updateBy$'),
    },
    {
        title: formatMessage('db.man_loc_detl.memo', '备注'),
        dataIndex: 'memo',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('memo'),
    },
];

//加载扩展字段
async function getColumns() {
    let fieldResp = await post('/api/matField/list', {
        unique: 1,
        fieldType: 1
    })
    let fieldResult = fieldResp.data;
    let tmp = state.columns;
    if (fieldResult.code == 200) {
        let data = fieldResult.data;

        data.forEach((item) => {
            tmp.push({
                title: formatMessage(item.language, item.describe),
                name: item.name,
                dataIndex: item.name,
                key: item.name,
                width: 140,
            })
        })

        tmp.push({
            title: formatMessage('common.operation', '操作'),
            name: 'oper',
            dataIndex: 'oper',
            key: 'oper',
            width: 140,
            fixed: 'right',
        })

        state.columns = tmp;
    } else if (result.code === 401) {
        message.error(result.msg);
        logout()
    } else {
        message.error(result.msg);
    }
}

const openSelect = () => {
    selectLocDetlChild.value.open = true;
}

const handleSelectLocDetlOk = (result) => {
    let tmp = [];

    if (tableData.value != undefined) {
        tmp = [...tableData.value]
    }

    for (let i = 0; i < result.length; i++) {
        let item = result[i]
        let flag = false;
        for (let j = 0; j < tmp.length; j++) {
            let tmpItem = tmp[j]
            if (item.id == tmpItem.id) {
                flag = true;
                break
            }
        }

        if (flag) {
            continue
        }

        tmp.push(item)
    }

    tableData.value = tmp;
}

const handleDel = (record) => {
    let data = tableData.value;
    let tmp = []

    for (let i = 0; i < data.length; i++) {
        let item = data[i]
        if (item.id == record.id) {
            continue
        }
        tmp.push(item)
    }
    tableData.value = tmp
}

const startFreeze = () => {
    if(state.selectedRowKeys.length == 0) {
        message.error(formatMessage("page.locFreeze.select.error", "请选择至少一条库存"));
        return;
    }

    post('/api/locDetl/freeze', {
        detlIds: state.selectedRowKeys,
        freeze: 1
    }).then(resp => {
        let result = resp.data;
        if (result.code == 200) {
            message.success(formatMessage('page.locFreeze.success', '冻结成功'));
            tableData.value = [];
            selectLocDetlChild.value.reload = true;
        } else {
            message.error(result.msg);
        }
    })
}

const stopFreeze = () => {
    if(state.selectedRowKeys.length == 0) {
        message.error(formatMessage("page.locFreeze.select.error", "请选择至少一条库存"));
        return;
    }

    post('/api/locDetl/freeze', {
        detlIds: state.selectedRowKeys,
        freeze: 0
    }).then(resp => {
        let result = resp.data;
        if (result.code == 200) {
            message.success(formatMessage('page.locFreeze.success', '解冻成功'));
            tableData.value = [];
            selectLocDetlChild.value.reload = true;
        } else {
            message.error(result.msg);
        }
    })
}

</script>

<script>
export default {
    name: '库存冻结'
}
</script>

<template>
    <div>
        <div class="table-header">
            <div>
                <a-button type="primary" @click="openSelect">提取库存</a-button>

                <a-button type="primary" style="margin-left: 5px;" @click="startFreeze">冻结</a-button>
                <a-button style="margin-left: 5px;" @click="stopFreeze">解冻</a-button>
            </div>
        </div>
        <a-table :row-selection="{ selectedRowKeys: state.selectedRowKeys, onChange: onSelectChange }"
            :data-source="tableData" :defaultExpandAllRows="false" :key="TABLE_KEY" rowKey="id"
            :scroll="{ y: 768, scrollToFirstRowOnChange: true }" :columns="state.columns"
            @resizeColumn="handleResizeColumn">
            <template #bodyCell="{ column, text, record }">
                <template v-if="column.dataIndex === 'oper'">
                    <div style="display: flex;justify-content: space-evenly;">
                        <a-button type="link" danger @click="handleDel(record)">{{ formatMessage('page.delete', '删除')
                            }}</a-button>
                    </div>
                </template>
            </template>
        </a-table>

        <SelectLocDetlView ref="selectLocDetlChild" @handle-ok="handleSelectLocDetlOk" />
    </div>
</template>

<style></style>
